@@ -1,7 +1,7 @@
 /*
- * @(#) $Id: cf.c 287 2017-01-21 19:15:36Z leres $ (XSE)
+ * @(#) $Id: cf.c 295 2018-07-21 20:20:41Z leres $ (XSE)
  *
- * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2015, 2017
+ * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2015, 2017, 2018
  *	Craig Leres
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,6 +43,7 @@ static char *dstrmerge(char *, char *);
 static void freelist(struct list *);
 static struct list *makelist(char *);
 static int readcf(const char *, struct cf *, int);
+static void fixpath(char **);
 
 /* Open, read and parse one config file */
 static int
@@ -51,7 +52,7 @@ readcf(const char *fn, struct cf *cf, int mustexist)
 	int n, d, errs, *ip;
 	char *cp, *cp2, *prefixend, **pp;
 	struct timespec ts;
-	FILE *f;
+	FILE *f, *f2;
 	struct section *sp;
 	struct list **lpp;
 	char *cp3, *include, *favicon, *appendhead, *appendtail;
@@ -118,7 +119,8 @@ readcf(const char *fn, struct cf *cf, int mustexist)
 		/* Quoted one line commands */
 		include = NULL;
 		favicon = NULL;
-		if ((pp = &cf->c_datefmt, strcasecmp(cp2, "datefmt") == 0) ||
+		if ((pp = &cf->c_css, strcasecmp(cp2, "css") == 0) ||
+		    (pp = &cf->c_datefmt, strcasecmp(cp2, "datefmt") == 0) ||
 		    (pp = &favicon, strcasecmp(cp2, "favicon") == 0) ||
 		    (pp = &include, strcasecmp(cp2, "include") == 0) ||
 		    (pp = &cf->c_indexfn, strcasecmp(cp2, "indexfn") == 0) ||
@@ -127,6 +129,7 @@ readcf(const char *fn, struct cf *cf, int mustexist)
 		    (pp = &cf->c_naildir, strcasecmp(cp2, "naildir") == 0) ||
 		    (pp = &cf->c_target, strcasecmp(cp2, "target") == 0) ||
 		    (pp = &cf->c_tz, strcasecmp(cp2, "tz") == 0)) {
+			cp3 = cp2;
 			if (*cp++ != '"') {
 				fprintf(stderr,
 				    "%s: %s missing leading double quote\n",
@@ -191,6 +194,32 @@ readcf(const char *fn, struct cf *cf, int mustexist)
 				include = NULL;
 				continue;
 			}
+
+			/* Fix up path to css file and fstat() */
+			if (strcasecmp(cp3, "css") == 0) {
+				fixpath(&cf->c_css);
+				f2 = fopen(cf->c_css, "r");
+				if (f2 == NULL) {
+					fprintf(stderr,
+					    "%s: readcf: fopen %s: %s\n",
+					    prog, cf->c_css, strerror(errno));
+					++errs;
+					continue;
+				}
+				if (fstat(fileno(f2), &sbuf) < 0) {
+					fprintf(stderr,
+					    "%s: readcf: fstat %s: %s\n",
+					    prog, cf->c_css, strerror(errno));
+					++errs;
+					continue;
+				}
+				(void)fclose(f2);
+				/* Update config timestamp if css is newer */
+				ts = stattim(&sbuf);
+				if (tscmp(&cf->c_tim, &ts, <))
+					cf->c_tim = ts;
+				continue;
+			}
 			continue;
 		}
 
@@ -500,12 +529,28 @@ dstrmerge(char *s1, char *s2)
 	return (t);
 }
 
+/* Prepend prefix to path in dynamic memory */
+static void
+fixpath(char **pp)
+{
+	char temp[PATH_MAX];
+
+	/* Only do this if we don't have an absolute path (and have a prefix) */
+	if (**pp != '/' && prefix[0] != '\0') {
+		(void)snprintf(temp, sizeof(temp), "%s%s", prefix, *pp);
+		free(*pp);
+		*pp = strdup(temp);
+	}
+}
+
 void
 freecf(struct cf *cf)
 {
 	struct section *sp, *sp2;
 
 	/* Single line options */
+	if (cf->c_css != NULL)
+		free(cf->c_css);
 	if (cf->c_datefmt != NULL)
 		free(cf->c_datefmt);
 	if (cf->c_indexfn != NULL)
