@@ -1,7 +1,7 @@
 /*
- * @(#) $Id: webindex.c 287 2017-01-21 19:15:36Z leres $ (XSE)
+ * @(#) $Id: webindex.c 292 2018-07-21 16:09:04Z leres $ (XSE)
  *
- * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017
+ * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018
  *	Craig Leres
  *
  * Redistribution and use in source and binary forms, with or without
@@ -16,7 +16,7 @@
  */
 #ifndef lint
 static const char copyright[] =
-    "@(#) Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017\nCraig Leres\n";
+    "@(#) Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018\nCraig Leres\n";
 #endif
 
 #include <sys/types.h>
@@ -116,8 +116,9 @@ const char defindexfn[] = "index.html";
 const char configfn[] = "webindex.conf";
 const char defdatefmt[] = "%l:%M%p";
 const char deftable[] = "<table>\n";
-const char debugtable[] = "<table border=1>\n";
-const char deftr[] = "<tr align=\"center\" valign=\"top\">\n";
+const char debugtable[] = "<table style=\"border: 1px;\">\n";
+const char deftr[] =
+    "<tr style=\"text-align: center; vertical-align: middle;\">\n";
 
 extern char *optarg;
 extern int optind, opterr, optopt;
@@ -266,7 +267,7 @@ process(const char *dname)
 	struct webfile *wp, *webfiles;
 	struct cf *cf;
 	struct section *sp;
-	size_t nfiles, nwebfiles;
+	size_t cc, nfiles, nwebfiles;
 	struct timespec mtim, ctim;
 	char *otz;
 	int d;
@@ -297,7 +298,7 @@ process(const char *dname)
 	indexfn = defindexfn;
 	table = deftable;
 	if (debug)
-		table = "<table border=1>\n";
+		table = debugtable;
 	tr = deftr;
 	tail = "\n";
 	otz = NULL;
@@ -360,7 +361,7 @@ process(const char *dname)
 		++force;
 		/* don't need to list a reason */
 	} else {
-		/* If it doesn't look like can update the index file, bail */
+		/* If it doesn't look like we can update the index file, bail */
 		if ((sbuf.st_mode & S_IFMT) == S_IFLNK) {
 			fprintf(stderr, "%s: process: %s%s%s: is a symlink\n",
 			    prog, affix, prefix, indexfn);
@@ -387,7 +388,8 @@ process(const char *dname)
 			++errors;
 			goto bail;
 		}
-		if (fgets(buf, sizeof(buf), f) == NULL) {
+		cc = fread(buf, 1, sizeof(buf), f);
+		if (cc == 0 && feof(f)) {
 			/* Zero length; force an index update */
 			++force;
 			reason = " (zero length)";
@@ -809,15 +811,23 @@ processfile(FILE *f, struct webfile *wp, struct cf *cf,
 	else
 		alt = name;
 
-	fprintf(f, "<img");
-	if (cf->c_imgborder != 1)
-		fprintf(f, " border=%d", cf->c_imgborder);
-	fprintf(f, "\nwidth=%d height=%d", w, h);
-	/* vspace helps to line stuff up when the thumbnail is small */
+	fprintf(f, "<img width=%d height=%d", w, h);
+	/* Only need inline css if we have a border or a small thumbnail */
 	i = (cf->c_iconsize - h) / 2;
-	if (i > 0)
-		fprintf(f, " vspace=%d", i);
-	fprintf(f, " src=\"%s\" alt=\"%s\"></a></td></tr>\n", icon, alt);
+	if (cf->c_imgborder > 0 || i > 0) {
+		fprintf(f, " style=\"");
+		if (cf->c_imgborder > 0) {
+			fprintf(f, "border: %dpx;", cf->c_imgborder);
+			if (i > 0)
+				fputc(' ', f);
+		}
+		/* Make text line up when the thumbnail is small */
+		if (i > 0)
+			fprintf(f, "margin: %dpx 0;", i);
+		fputc('"', f);
+	}
+
+	fprintf(f, "\n    src=\"%s\" alt=\"%s\"></a></td></tr>\n", icon, alt);
 
 	/* Filename (break long ones) */
 	if (cf->c_namelen >= 0 && (cf->c_flags & C_NO_NAME) == 0) {
@@ -1208,14 +1218,21 @@ header(FILE *f, struct cf *cf)
 		zone[0] = '+';
 	(void)sprintf(zone + 1, "%04d", z);
 #endif
+	fprintf(f, "<!DOCTYPE html>\n");
 	fprintf(f, "<!-- %s\n    Version %s (this file created on %s %s) -->\n",
 	    magic, version, date, zone);
+	fprintf(f, "<html lang=\"en\"><head>\n");
 	if (cf->c_favicon != NULL)
-		fprintf(f, "<html><head>\n"
-		    "<link rel=\"shortcut icon\" href=\"%s\">\n<title>\n",
+		fprintf(f, "<link rel=\"shortcut icon\" href=\"%s\">\n",
 		    cf->c_favicon);
-	else
-		fprintf(f, "<html><head><title>\n");
+	if (cf->c_css != NULL)
+		fprintf(f, "<link rel=\"stylesheet\" type=\"text/css\""
+		    " href=\"%s\" />\n", cf->c_css);
+	fprintf(f, "<meta http-equiv=\"Content-type\""
+	    " content=\"text/html;charset=UTF-8\">\n");
+	fprintf(f, "<meta name=\"viewport\""
+	    " content=\"width=device-width, initial-scale=1\">\n");
+	fprintf(f, "<title>\n");
 	if (cf->c_title != NULL)
 		fprintf(f, "%s", cf->c_title);
 	else
