@@ -1,7 +1,7 @@
 /*
- * @(#) $Id: wpbm.c 267 2015-07-04 21:54:44Z leres $ (XSE)
+ * @(#) $Id: wpbm.c 287 2017-01-21 19:15:36Z leres $ (XSE)
  *
- * Copyright (c) 1999, 2000, 2008, 2009, 2010, 2015
+ * Copyright (c) 1999, 2000, 2008, 2009, 2010, 2015, 2017
  *	Craig Leres
  *
  * Redistribution and use in source and binary forms, with or without
@@ -16,6 +16,7 @@
  */
 
 #include <sys/types.h>
+#include <sys/stat.h>
 
 #include <fcntl.h>
 #include <stdio.h>
@@ -31,21 +32,20 @@
 #include "wpbm.h"
 
 int
-parsepbm(/* const */ char *image, int *wp, int *hp)
+parsepbm(/* const */ char *image, int *wp, int *hp, struct timespec *mtimp)
 {
 	FILE *f;
 	pixval maxval;
 	int format;
+	struct stat sbuf;
 
 	f = pm_openr(image);
 	if (f == NULL)
 		return (0);
 
-#ifdef notdef
 	/* XXX ignore errors */
-	if (tp != NULL && fstat(fileno(f), &sbuf) >= 0)
-		*tp = sbuf.st_mtime;
-#endif
+	if (mtimp != NULL && fstat(fileno(f), &sbuf) >= 0)
+		*mtimp = sbuf.st_mtim;
 
 	ppm_readppminit(f, wp, hp, &maxval, &format);
 
